<?php
  include_once("header.php");
  include_once("formvalidator.php"); 
  if(!$start)$start=0;
if($login==1)
{
    /*
    //
   if($action=="add")
   {
       $validator = new FormValidator();
        $validator->addValidation('first','req','من فضلك ادخل الاسم') ;
        $validator->addValidation('second','req','من فضلك ادخل اٍسم الاب') ;
        $validator->addValidation('third','req','من فضلك ادخل الجد') ;
        $validator->addValidation('family','req','من فضلك ادخل العائله') ;
        $validator->addValidation('email','req','من فضلك ادخل  الايميل') ;
        $validator->addValidation('email','email','من فضلك ادخل  ايميل صحيح') ;
        $validator->addValidation('password','req','من فضلك ادخل كلمة المرور') ;
        $validator->addValidation('mobile','req','من فضلك ادخل رقم الجوال') ;
         $validator->addValidation('mobile','num','من فضلك ادخل رقم جوال صحيح') ;
        $validator->addValidation('student_id','req','من فضلك ادخل رقم الطالب الجامعى') ;
        $validator->addValidation('student_id','num','من فضلك ادخل رقم الطالب الجامعى') ;
        $validator->addValidation('faculty','req','من فضلك ادخل الكليه') ;
        $validator->addValidation('class','req','من فضلك ادخل  القسم') ;
        $validator->addValidation('level','req','من فضلك ادخل المستوى') ;
        $validator->addValidation('subject','req','من فضلك ادخل الماده') ;
        if(isset($submit)&&$validator->ValidateForm()&&$email==$remail&&$password==$repassword)
        {
          if(in_array(strtolower(end(explode(".",$_FILES['pic']['name']))), $pic_types)
            && strlen($_FILES['pic']['name'])!=0
            &&move_uploaded_file($_FILES["pic"]["tmp_name"],"../media/user/".time().$_FILES["pic"]["name"]))
            {
                $pic_name = time().$_FILES["pic"]["name"];
                $filetype = strtolower(end(explode('.',$pic_name)));
                $filesize = $_FILES["pic"]["size"];
               // mysql_query("insert into offer_img values('','$offer_id','$pic_name')")or die(mysql_error());
            }
           mysql_query("insert into user values('','$first','$second','$third','$family','$user_name',
           '$email','".md5($password)."','$mobile','$student_id','$faculty','$class','$level','$subject',
           '$pic_name','0')");
           $sub= "تم التسجيل بنجاح"; 
        }
        else
        {
          $error_hash = $validator->GetErrors();
            foreach($error_hash as $inpname => $inp_err)
            {
                $msg .= "$inp_err<br>\n";
            }
            $sub .= Template_Array($admin_template."/user_add.html",0);  
        }
   }
   elseif($action=="edit")
   {
        if(isset($submit)&&$email==$remail&&$password==$repassword)
        {
          if(in_array(strtolower(end(explode(".",$_FILES['pic']['name']))), $pic_types)
            && strlen($_FILES['pic']['name'])!=0
            &&move_uploaded_file($_FILES["pic"]["tmp_name"],"../media/user/".time().$_FILES["pic"]["name"]))
            {
                $pic_name = time().$_FILES["pic"]["name"];
                $filetype = strtolower(end(explode('.',$pic_name)));
                $filesize = $_FILES["pic"]["size"];
               // mysql_query("insert into offer_img values('','$offer_id','$pic_name')")or die(mysql_error());
            }
           mysql_query("update user set first='$first',second='$second',third='$third',family='$family',
           user_name='$user_name',email='$email',password='".md5($password)."',mobile='$mobile',
           student_id='$student_id',faculty='$faculty',class='$class',level='$level',subject='$subject',
           pic='$pic_name' where id='$id'");
           $sub= "تم التسجيل بنجاح"; 
        }
        else
        {
            $userquery=mysql_query("select * from user where id='$id'");
            while($row=mysql_fetch_array($userquery))
            {
                extract($row);
            }
         
            $sub .= Template_Array($admin_template."/user_add.html",0);  
        }
   } 
   elseif($action=="delete")
   {
       mysql_query("delete from user where id='$id'");
       $msg="تم الحذف";
        $sub .= Template_Array("$admin_template./staticmsg.html");
        $sub =user();
   }
   elseif($action=="state")
    {
        $offer_query = mysql_query("SELECT * FROM user WHERE id='$id'",$connection);
        $offer_fetch = mysql_fetch_array($offer_query);
        extract($offer_fetch);
        if($state==1)
        {
            $state=0;
            $msg = "تم التعطيل";
        }
        else
        {
            $state=1;
            $msg = "تم التنشيط ";
        }
        mysql_query("update user set state='$state' where id='$id'");
        $sub =user();
    }
   elseif($action=="show")
    {
       $userquery=mysql_query("select * from user where id='$id'");
            while($row=mysql_fetch_array($userquery))
            {
                extract($row);
            }
         
            $sub .= Template_Array($admin_template."/user_show.html",0);  
    }
    * 
    */
  if($action=="addgroup")
    {
      if(isset($submit))
      {
         mysql_query("insert into groups values('','$name','1','$cat')")or die(mysql_error());
         $msg="تم اضافة المجموعه بنجاح";
          $sub = group();
      }
     else
     {
         $supportquery=mysql_query("select * from support_cat");
         while($supportrow=mysql_fetch_array($supportquery))
         {
            extract($supportrow);
            $cats .="<option value=$id>$name</option>";
         }
         $sub = Template_Array("$site_template/admin/group_add.html",0); 
     }
    }
  elseif($action=="editgroup")
  {
    if(isset($submit))
    {
      mysql_query("update groups set name='$name',support_cat='$cat' where group_id='$id'");
      $msg="تم التعديل بنجاح";
      $sub = group();
    }
    else
    {
      $edit=mysql_query("select * from group where group_id='$id'");
      while($editrow=mysql_fetch_array($edit))
      {
        extract($editrow);
      }
       $supportquery=mysql_query("select * from support_cat");
         while($supportrow=mysql_fetch_array($supportquery))
         {
            extract($supportrow);
            $cats .="<option value=$id>$name</option>";
         }
      $sub = Template_Array("$site_template/admin/group_add.html",0);
    }
  } 
  elseif($action=="stategroup")
  {
    $pages_query = mysql_query("SELECT * FROM groups where group_id='$id'",$connection);
        $pages_fetch = mysql_fetch_array($pages_query);
        extract($pages_fetch);
        if($state==1)
         {
            $state=0;
            $msg = "تم التعطيل";
         }
        else
         {
           $state=1;
           $msg = "تم التنشيط ";
         }
        mysql_query("update groups set state='$state' where group_id='$id'"); 
        $sub = group();
  }
  elseif($action=="showuser")
  {
    $sub=user();
  } 
   elseif($action=="adduser")
   {
       $validator = new FormValidator();
        $validator->addValidation('user_name','req','من فضلك ادخل  الاسم') ;
       $validator->addValidation('email','req','من فضلك ادخل  الايميل') ;
        $validator->addValidation('email','email','من فضلك ادخل  ايميل صحيح') ;
        $validator->addValidation('password','req','من فضلك ادخل كلمة المرور') ;
        $validator->addValidation('mobile','req','من فضلك ادخل رقم الجوال') ;
         $validator->addValidation('mobile','num','من فضلك ادخل رقم جوال صحيح') ;
      
       if(isset($submit)&&$validator->ValidateForm())
      {
          
        mysql_query("insert into user values('','$group','$user_name',
           '".md5($password)."','$email','$country','$city','$phone','$mobile','1')");
           $sub= "تم التسجيل بنجاح";
      }
      else
      {
          $groupquery=mysql_query("select * from groups");
          while($grouprow=mysql_fetch_array($groupquery))
          {
            extract($grouprow);
            $groups .="<option value=$group_id>$name</option>";
          }
          $error_hash = $validator->GetErrors();
            foreach($error_hash as $inpname => $inp_err)
            {
                $msg .= "$inp_err<br>\n";
            } 
        $sub = Template_Array("$site_template/admin/user_add.html",0);
      }
   }
   elseif($action=="edit")
   {
       $validator = new FormValidator();
        $validator->addValidation('user_name','req','من فضلك ادخل  الاسم') ;
       $validator->addValidation('email','req','من فضلك ادخل  الايميل') ;
        $validator->addValidation('email','email','من فضلك ادخل  ايميل صحيح') ;
        $validator->addValidation('password','req','من فضلك ادخل كلمة المرور') ;
        $validator->addValidation('mobile','req','من فضلك ادخل رقم الجوال') ;
         $validator->addValidation('mobile','num','من فضلك ادخل رقم جوال صحيح') ;

       if(isset($submit)&&$validator->ValidateForm())
       {
          mysql_query("update user set group_id='$group',user_name='$user_name',
          password='".md5($password)."',email='$email',country='$country',
          city='$city',phone='$phone',mobile='$mobile' where id='$user_id'");
          $msg="تم التعديل";
          $sub= user();
       }
       else
       {
           $userquery=mysql_query("select * from user where id='$user_id'");
           while($userrow=mysql_fetch_array($userquery))
           {
             extract($userrow);
           }
           $groupquery=mysql_query("select * from groups");
          while($grouprow=mysql_fetch_array($groupquery))
          {
            extract($grouprow);
            $groups .="<option value=$group_id>$name</option>";
          }
          $error_hash = $validator->GetErrors();
            foreach($error_hash as $inpname => $inp_err)
            {
                $msg .= "$inp_err<br>\n";
            } 
        $sub = Template_Array("$site_template/admin/user_add.html",0);
       }
   }
   elseif($action=="delete")
   {
     mysql_query("delete from user where id='$user_id'");
     $msg="تم الحذف بنجاح";
     $sub=user();
   }
   elseif($action=="stateuser")
   {
     $pages_query = mysql_query("SELECT * FROM user where id='$user_id'",$connection);
        $pages_fetch = mysql_fetch_array($pages_query);
        extract($pages_fetch);
        if($state==1)
         {
            $state=0;
            $msg = "تم التعطيل";
         }
        else
         {
           $state=1;
           $msg = "تم التنشيط ";
         }
        mysql_query("update user set state='$state' where id='$user_id'"); 
        $sub = user();
   }
    
   else
   {
     $sub= group();
   }
}
else
{
    echo Template_Array("$site_template/admin/login.html");
    die();
}
  include_once("footer.php");
?>
